@@ -278,6 +278,14 @@ class account():
             print msg
         except httplib.BadStatusLine:
             print "Network error - BadStatusLine"
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
+        except httplib.sslerror:
+            print "Network error - SslError"
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
 
 
     def getMentions(self, auto=0, older=False, get_count=20, * args):
@@ -356,8 +364,7 @@ class account():
                     rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._ENABLE_LED,rpc_args=(self._LED_PATTERN,"",""),use_system_bus=True)
                     rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._VIBRATE,rpc_args=(self._VIBRATE_PATTERN,"",""),use_system_bus=True)
                     #n.attach_to_widget(self.controller.ui.window)
-                
-                n.show()
+                    n.show()
 
         except IOError, e:
             print "error"
@@ -379,7 +386,15 @@ class account():
             print msg
         except httplib.BadStatusLine:
             print "Network error - BadStatusLine"
-
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
+        except httplib.sslerror:
+            print "Network error - SslError"
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
+                
     def getDMs(self, auto=0, older=False, get_count=20, * args):
         if (self.api == None):
             if (self.connect() != True):
@@ -470,7 +485,15 @@ class account():
             print msg
         except httplib.BadStatusLine:
             print "Network error - BadStatusLine"
-
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
+        except httplib.sslerror:
+            print "Network error - SslError"
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
+                
     def getFriends(self, auto=0, older=False, get_count=20, * args):
         if (self.api == None):
             if (self.connect() != True):
@@ -526,7 +549,15 @@ class account():
             print msg
         except httplib.BadStatusLine:
             print "Network error - BadStatusLine"
-
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
+        except httplib.sslerror:
+            print "Network error - SslError"
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
+                
     def getPublic(self, auto=0, older=False, get_count=20, * args):
         if (self.api == None):
             if (self.connect() != True):
@@ -612,7 +643,14 @@ class account():
             print msg
         except httplib.BadStatusLine:
             print "Network error - BadStatusLine"
-
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
+        except httplib.sslerror:
+            print "Network error - SslError"
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
 
     def getUserHistory(self, friend="", auto=0, older=False, get_count=20, * args):
         if (self.api == None):
@@ -673,7 +711,14 @@ class account():
             print msg
         except httplib.BadStatusLine:
             print "Network error - BadStatusLine"
-
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
+        except httplib.sslerror:
+            print "Network error - SslError"
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
 
     def getSearch(self, searchTerms="", auto=0, older=False, get_count=20, * args):
         print "performing search"
@@ -744,7 +789,15 @@ class account():
                     note.system_note_dialog(msg)
             except httplib.BadStatusLine:
                 print "Network error - BadStatusLine"
-
+                if (auto == 0):
+                    note = osso.SystemNote(self.osso_c)
+                    note.system_note_dialog("Network error occured. Please try again")
+            except httplib.sslerror:
+                print "Network error - SslError"
+                if (auto == 0):
+                    note = osso.SystemNote(self.osso_c)
+                    note.system_note_dialog("Network error occured. Please try again")
+                
     def getTrends(self, *args):
 
         print "getting Trending topics"
@@ -783,7 +836,14 @@ class account():
                 note.system_note_dialog(msg)
         except httplib.BadStatusLine:
             print "Network error - BadStatusLine"
-
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
+        except httplib.sslerror:
+            print "Network error - SslError"
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
 
     def get_specific_tweet(self,username,tweet_id):
         try:
@@ -845,6 +905,18 @@ class account():
 
             result = note.system_note_infoprint(msg)
             return False
+        except httplib.BadStatusLine:
+            print "Network error - BadStatusLine"
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
+            return False
+        except httplib.sslerror:
+            print "Network error - SslError"
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
+            return False
 
     def FavouriteTweet(self, widget, id, *args):
         
@@ -978,6 +1050,16 @@ class account():
             note = osso.SystemNote(self.osso_c)
             note.system_note_dialog(msg)
             print msg
+        except httplib.BadStatusLine:
+            print "Network error - BadStatusLine"
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
+        except httplib.sslerror:
+            print "Network error - SslError"
+            if (auto == 0):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("Network error occured. Please try again")
         
     def escapeText(self, text):
         #switch certain chars for escape sequences
